<template>
  <div :id="domId"></div>
</template>
<script>
export default {
  name: "pie",
  props: {
    seriesName:{
      type:String,
      default:'预警事件'
    },
    radiusType:{
      type:[String,Array],
      default:()=>{
        return "50%"
      }
    },
    seriesData:{
      type:Array,
      default:()=>{
        return []
      }
    },
    domId:{
      type:String,
      default:"myChartPie"
    }
  },
  watch: {
    seriesData:{
      handler:function(val,oldVal){
        this.init()
        // if(val !== oldVal){
        //   this.init()
        // }
      },
      deep:true
    },
    "TreeDataPool.showTreeBox":{
      handler:function(val,oldVal){
        if(val !== oldVal){
          this.handleResize()
        }
      }
    }
  },
  computed: {
    options() {
      return {
        tooltip: {
          trigger: "item",
          formatter: "{a} <br/>{b}: {c} ({d}%)"
        },
        legend: {
          //show: false,
          type:"scroll",
          orient: "horizontal",
          left: '10px',
          right: '10px',
          top: '35px',
          align: 'auto',
          textStyle: {
            color: 'rgba(136,136,136,.6)'
          },
          pageTextStyle:{
            color: 'rgba(136,136,136,.6)'
          }
        },
        series: [
          {
            name: this.seriesName,
            fontSize: 14,
            type: "pie",
            radius: this.radiusType,
            top: 40,
            height: "90%",
            // labelLine: {
            //   length: 15
            // },
            //center: ["50%", "95%"],
            avoidLabelOverlap: false,
            itemStyle: {
                emphasis: {
                    shadowBlur: 10,
                    shadowOffsetX: 0,
                    shadowColor: 'rgba(0, 0, 0, 0.5)'
                },
                color: (parrams)=>{
                  let colorList = [
                    '#9C05FC','#0B8CFC', '#43F0EB', '#FACB62', '#FF0000', '#FE8463'
                  ]
                  return colorList[parrams.dataIndex]
                }
            },
            labelLine: {
              normal: {
                show: true
              }
            },
            minShowLabelAngle:20,
            data: this.seriesData
          }
        ]
      };
    }
  },
  data() {
    return {
      myChart:Object
    };
  },
  methods: {
    init(){
      this.myChart.setOption(this.options)
    },
    handleResize(){
      this.myChart.resize()
    }
  },
  mounted() {
    this.myChart = this.$echarts.init(document.getElementById(this.domId));
    this.myChart.setOption(this.options);
    this.myChart.resize();
  },
  destroyed() {
    this.myChart.dispose()
  },
};
</script>
<style lang="scss">
#myChartPie{
  width: 100%;
  height: 100%;
}
</style>
